---
layout: landing
comment: no
title: 'John Snow Labs <span>State of the Art Natural Language Processing in Python</span>'
excerpt: John Snow Labs' NLP & LLM ecosystem include software libraries for state-of-the-art AI at scale, Responsible AI, No-Code AI, and access to over 20,000 models for Healthcare, Legal, Finance, and Visual  NLP.
seotitle: Spark NLP – State of the Art NLP in Python, Java, and Scala – John Snow Labs.
permalink: /
header: true
article_header:
  actions:
    - text: Get Started
      type: active
      url: /docs/en/jsl/install
    - text: View Demo
      type: trans
      url: /demos
    - text: '<i class="fab fa-github"></i> GitHub'
      type: trans
      url: https://github.com/JohnSnowLabs/spark-nlp-workshop/tree/master/tutorials/Certification_Trainings
    # - text: '<i class="fab fa-slack-hash"></i> Slack'
    #   type: outline-theme-dark
    #   url: https://join.slack.com/t/spark-nlp/shared_invite/enQtNjA4MTE2MDI1MDkxLWVjNWUzOGNlODg1Y2FkNGEzNDQ1NDJjMjc3Y2FkOGFmN2Q3ODIyZGVhMzU0NGM3NzRjNDkyZjZlZTQ0YzY1N2I
  height: 20vh
  theme: dark
data:
  sections:
    - threeblocks:
        - title: Natively Python
          image:
            src: /assets/images/home/natively_python.svg
          excerpt: Seamless integration of John Snow Labs' ecosystem with common Python libraries.
        - title: Powerful One-Liners
          image:
            src: /assets/images/home/powerfull_oneliners.svg
          excerpt: 10,000+ models in 250+ languages are at your fingertips with one line of code.
        - title: Open Source
          image:
            src: /assets/images/home/open_source_home.svg
          excerpt: Open Source software, widely deployed, back by an active community.
    - title: Powered by the most widely used <a target="_blank" href="https://www.johnsnowlabs.com/spark-nlp/">NLP library</a> in the enterprise
      top: yes
      excerpt: Gradient Flow NLP Survey, 2021.
      bigimage: /assets/images/home/nlp_libraries.png
      

    - title: Quick and Easy
      install: yes
      excerpt: Available on <a href="https://pypi.org/project/johnsnowlabs/" target="_blank">PyPI</a> and <a href="https://anaconda.org/johnsnowlabs/johnsnowlabs" target="_blank">Conda</a>. 
      actions:
        - text: Install JohnSnowLabs
          type: big_btn
          url: /docs/en/jsl/install

    - title: Complete NLP Ecosystem   
      ecosystem: yes
      tab-header:
        - text: <span>Free</span>Spark NLP
        - text: <span>Free</span>NLP Display
        - text: <span>Free</span>NLP Test
        - text: <span>Free</span>NLP Lab
        - text: Healthcare NLP
        - text: Finance NLP
        - text: Legal NLP
        - text: Visual NLP
      tab-body:
        - text: Spark NLP
          description: Open-Source text processing library for Python, Java, and Scala. It provides production-grade, scalable, and trainable versions of the latest research in natural language processing.
          img: /assets/images/home/23_05_2023.jpg

        - text: NLP Display
          description: Open-Source Python library for visualizing the annotations generated with Spark NLP. 
          img: /assets/images/nlpdisplay.png

        - text: NLP Test
          description: Deliver safe and effective models with an open-source library by generating & running over 50 test types on the most popular NLP libraries & tasks.
          img: /assets/images/home/nlp_test.jpg

        - text: NLP Lab
          link: https://www.johnsnowlabs.com/nlp-lab/
          description: Free End-to-End No Code NLP Platform for teams that want to collaborately annotate documents and train models.
          img: /assets/images/home/nlp_lab.png

        - text: Healthcare NLP
          link: https://www.johnsnowlabs.com/healthcare-nlp/
          description: State-of-the-Art NLP Library for understanding clinical and biomedical text. 
          img: /assets/images/home/HealthcareNLP.jpg

        - text: Finance NLP
          link: https://www.johnsnowlabs.com/finance-nlp/
          description: State-of-the-Art NLP Library for understanding financial documents. 
          img: /assets/images/home/finance_nlp.png

        - text: Legal NLP
          link: https://www.johnsnowlabs.com/legal-nlp/
          description: State-of-the-Art NLP Library for understanding legal documents.
          img: /assets/images/home/legal_nlp.png

        - text: Visual NLP
          link: https://www.johnsnowlabs.com/visual-nlp/
          description: Visual document understanding library for extracting information from images, scanned documents, PDFs, DOCX, and DICOM files.
          img: /assets/images/home/visual_nlp.png

    - title: Trusted By
      trusted: yes
      featureitem: sponsor
      children:
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/thumb/9/96/Microsoft_logo_%282012%29.svg/500px-Microsoft_logo_%282012%29.svg.png
            url: https://www.microsoft.com/
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/thumb/2/2f/Google_2015_logo.svg/500px-Google_2015_logo.svg.png
            url: https://cloud.google.com/
            style: "padding: 25px;"
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/thumb/a/a9/Amazon_logo.svg/500px-Amazon_logo.svg.png
            url: https://amazon.com/
            style: "padding: 25px;"
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/thumb/0/0e/Intel_logo_%282020%2C_light_blue%29.svg/200px-Intel_logo_%282020%2C_light_blue%29.svg.png
            url: https://www.intel.com/
            style: "padding: 25px;"
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/thumb/5/51/IBM_logo.svg/500px-IBM_logo.svg.png
            url: https://www.ibm.com/
            style: "padding: 25px;"
        - title:
          image:
            src: https://databricks.com/wp-content/themes/databricks/assets/images/header_logo_2x.png
            url: https://databricks.com/
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/thumb/d/df/ArcGIS_logo.png/600px-ArcGIS_logo.png
            url: https://www.esri.com/en-us/home
            style: "padding: 20px;"
        - title:
          image:
            src: https://i.pinimg.com/originals/cf/bc/c6/cfbcc6418a4e7ba4c780c101559ff9e1.jpg
            url: https://www.shell.com/
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/thumb/c/ca/Walmart_logo.svg/800px-Walmart_logo.svg.png
            url: https://www.walmart.com/
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/c/c2/Allianz_rgb_72.jpg
            url: https://www.allianz.com/en.html
            style: "padding: 17px;"
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/thumb/f/f9/DaimlerLogo.svg/1200px-DaimlerLogo.svg.png
            url: https://www.daimler.com/en/
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/thumb/c/c9/Nuance_Communications_logo_2018.svg/640px-Nuance_Communications_logo_2018.svg.png
            url: https://www.nuance.com/index.html
        - title:
          image:
            src: https://www.thetradedesk.com/assets/global/ttd-logo.svg
            url: https://www.thetradedesk.com/us
        - title:
          image:
            src: /assets/images/home/Clarivate_Analytics_logo.svg.png
            url: https://clarivate.com
        - title:
          image:
            src: https://logos-world.net/wp-content/uploads/2020/12/Ericsson-Logo.png
            url: https://www.ericsson.com/
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/9/95/Infosys_logo.svg
            url: https://www.infosys.com/
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/thumb/6/68/Novartis-Logo.svg/800px-Novartis-Logo.svg.png
            url: https://www.novartis.com/
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/thumb/a/ab/Amgen.svg/1280px-Amgen.svg.png
            url: https://www.amgen.com/
        - title:
          image:
            src: https://give.providence.org/WA/hospiceseattle/image/providence-health-services.svg
            url: https://www.providence.org/
        - title:
          image:
            src: https://cdn-static.findly.com/wp-content/uploads/sites/803/2019/03/Highmarkhealth.jpg
            url: https://www.highmarkhealth.org/
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/thumb/5/50/Oracle_logo.svg/1280px-Oracle_logo.svg.png
            url: https://www.oracle.com/index.html
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/thumb/5/56/Deloitte.svg/1024px-Deloitte.svg.png
            url: https://www2.deloitte.com/
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/thumb/9/9d/L%27Or%C3%A9al_logo.svg/1280px-L%27Or%C3%A9al_logo.svg.png
            url: https://www.loreal.com/en/
        - title:
          image:
            src: https://companieslogo.com/img/orig/IDXX-d9c286e7.png?t=1592707160
            url: https://www.idexx.com/en/
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/thumb/8/81/Verizon_2015_logo_-vector.svg/500px-Verizon_2015_logo_-vector.svg.png
            url: https://www.verizonwireless.com/
            style: "padding: 10px;"
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/f/fa/Indeed_logo.png
            url: https://www.indeed.com/
            style: "padding: 10px;"
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/thumb/9/98/Capital_One_logo.svg/500px-Capital_One_logo.svg.png
            url: https://www.capitalone.com/
            style: "padding: 10px;"
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/thumb/3/37/Viacom_logo.svg/500px-Viacom_logo.svg.png
            url: https://www.viacbs.com/
            style: "padding: 10px;"
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/thumb/9/93/Mck_logo_pos_col_rgb.svg/500px-Mck_logo_pos_col_rgb.svg.png
            url: https://www.mckesson.com/
            style: "padding: 10px;"
        - title:
          image:
            src: /assets/images/home/merck.jpg
            url: https://www.merck.com/
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/thumb/1/17/Roche_Logo.svg/500px-Roche_Logo.svg.png
            url: https://www.roche.com/
            style: "padding: 25px;"
        - title:
          image:
            src: https://selectdata.com/wp-content/uploads/2019/12/logo.png
            url: https://selectdata.com/
            style: "padding: 10px;"
        - title:
          image:
            src: https://www.uipath.com/hs-fs/hubfs/UiReBoot-Logo-TM.jpg?width=3091&name=UiReBoot-Logo-TM.jpg
            url: https://www.uipath.com/
        - title:
          image:
            src: https://connection.asco.org/sites/asco_connection/files/styles/article_image/public/pictures/ASCO_March_CancerLinQ.jpg
            url: https://www.cancerlinq.org/

        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/thumb/0/01/1_Heart_Aetna_logo_sm_rgb_violet.png/800px-1_Heart_Aetna_logo_sm_rgb_violet.png
            url: https://www.aetna.com/
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/thumb/3/34/DocuSign_logo.png/800px-DocuSign_logo.png
            url: https://www.docusign.fr/
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/thumb/f/f1/UCLA-HealthSystem-Logo-RGB.png/800px-UCLA-HealthSystem-Logo-RGB.png
            url: https://www.uclahealth.org/
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/thumb/5/53/Rand_Corporation_logo.svg/600px-Rand_Corporation_logo.svg.png
            url: https://www.rand.org/
            style: "padding: 29px;"

        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/fr/thumb/8/8e/Centre_national_de_la_recherche_scientifique.svg/2048px-Centre_national_de_la_recherche_scientifique.svg.png
            url: https://iscpif.fr/
            style: "padding: 30px;"
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/thumb/d/de/Imperial_logo.svg/500px-Imperial_logo.svg.png
            url: https://www.imperial.ac.uk/
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/6/6b/Georgia_Tech_shortened_logo.png
            url: https://www.gatech.edu/
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/5/57/Stanford_logo_%282008-2012%29.png
            url: https://www.stanford.edu/
        - title:
          image:
            src: https://www.iisc.ac.in/wp-content/uploads/2020/08/IISc_Master_Seal_Black_Transparent.png
            url: https://www.iisc.ac.in/
        - title:
          image:
            src: https://www.wikicu.com/images/thumb/b/ba/BastardShield.png/300px-BastardShield.png
            url: https://www.columbia.edu/
            style: "padding: 25px;"
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/en/thumb/7/79/University_of_Chicago_shield.svg/1200px-University_of_Chicago_shield.svg.png
            url: https://www.uchicago.edu/
            style: "padding: 29px;"
        - title:
          image:
            src: https://i.pinimg.com/originals/be/30/48/be304864a1e2a400320041cffb5acb3f.png
            url: https://www.ox.ac.uk/
            style: "padding: 29px;"
        - title:
          image:
            src: https://u-paris.fr/wp-content/uploads/2019/03/Universite_Paris_logo_horizontal.jpg
            url: https://u-paris.fr/en/
        - title:
          image:
            src: https://upload.wikimedia.org/wikipedia/commons/f/f9/Logo_Med_Uni_Graz.png
            url: https://www.medunigraz.at/
            style: "padding: 20px;"

    - title: Active Community Support
      theme: dark
      bottom: yes
      topclass: bottom_section
      excerpt:
      classmenu: three_a
      actions:
        - text: View Demo
          type: trans
          url: /demos
        - text: Examples
          type: trans
          url: https://github.com/JohnSnowLabs/spark-nlp-workshop/tree/master/tutorials/Certification_Trainings
        - text: '<i class="fab fa-slack-hash"></i> Slack'
          type: trans
          url: https://join.slack.com/t/spark-nlp/shared_invite/zt-198dipu77-L3UWNe_AJ8xqDk0ivmih5Q
      background_color: "#0098DA"


---